@@ -476,7 +476,8 @@ QString DolphinViewContainer::caption() const
     }
 
     KFilePlacesModel *placesModel = DolphinPlacesModelSingleton::instance().placesModel();
-    const auto& matchedPlaces = placesModel->match(placesModel->index(0,0), KFilePlacesModel::UrlRole, QUrl(url().adjusted(QUrl::StripTrailingSlash).toString(QUrl::FullyEncoded).append("/?")), 1, Qt::MatchRegExp);
+    const QString pattern = url().adjusted(QUrl::StripTrailingSlash).toString(QUrl::FullyEncoded).append("/?");
+    const auto& matchedPlaces = placesModel->match(placesModel->index(0,0), KFilePlacesModel::UrlRole, QRegularExpression::anchoredPattern(pattern), 1, Qt::MatchRegularExpression);
 
     if (!matchedPlaces.isEmpty()) {
         return placesModel->text(matchedPlaces.first());
@@ -727,6 +728,18 @@ void DolphinViewContainer::slotUrlSelectionRequested(const QUrl& url)
     m_view->markUrlAsCurrent(url); // makes the item scroll into view
 }
 
+void DolphinViewContainer::disableUrlNavigatorSelectionRequests()
+{
+    disconnect(m_urlNavigator.get(), &KUrlNavigator::urlSelectionRequested,
+        this, &DolphinViewContainer::slotUrlSelectionRequested);
+}
+
+void DolphinViewContainer::enableUrlNavigatorSelectionRequests()
+{
+    connect(m_urlNavigator.get(), &KUrlNavigator::urlSelectionRequested,
+        this, &DolphinViewContainer::slotUrlSelectionRequested);
+}
+
 void DolphinViewContainer::redirect(const QUrl& oldUrl, const QUrl& newUrl)
 {
     Q_UNUSED(oldUrl)
